Crate dydx

Crate dydx 

dYdX v4 asynchronous client.

dYdX v4 architecture introduces nodes and the indexer for read-write and read-only operations accordingly. Multiple entrypoints to the system are reflected in the client interface to allow for a highly customized use.

The client allows:

  • manage orders and funds (via NodeClient)
  • query the dYdX network (via NodeClient and IndexerClient)
  • get testnet token funds (via FaucetClient, gated by feature faucet, turned on by default)
  • transfer funds between Noble and dYdX (via NobleClient, gated by feature noble, turned on by default)

Telemetry

The feature telemetry is turned on by default and provides metrics collection in a vendor-agnostic way. This allows to use any compatible metrics exporter. To see what metrics are collected check the public constants of the module telemetry. Many provided examples (see below) use metrics-observer as an example metrics exporter allowing to track them in a separate terminal.

Examples

Explore many elaborated examples in the repository. Note - to run examples you need protoc as metrics-exporter-tcp uses it during the build.

Modules

config
Client configuration.
faucet
Testnet tokens.
indexer
Indexer client.
noble
Noble client.
node
Node client.
telemetry
Telemetry.