Accounts

Struct Accounts 

pub struct Accounts<'a> { /* private fields */ }
Accounts dispatcher.

Check the example.

Implementations

Source

impl<'a> Accounts<'a>

pub async fn get_subaccounts( &self, address: &Address, ) -> Result<AddressResponse, Error>

Query for all subaccounts infos.

Compare with Self::get_subaccount.

Reference.

pub async fn get_subaccount( &self, subaccount: &Subaccount, ) -> Result<SubaccountResponseObject, Error>

Query for the subaccount, its current perpetual and asset positions, margin and collateral.

Reference.

pub async fn get_parent_subaccount( &self, subaccount: &ParentSubaccount, ) -> Result<ParentSubaccountResponseObject, Error>

Query for the parent subaccount, its child subaccounts, equity, collateral and margin.

Reference.

pub async fn list_positions( &self, subaccount: &Subaccount, opts: Option<ListPositionsOpts>, ) -> Result<Vec<PerpetualPositionResponseObject>, Error>

👎Deprecated since 0.3.0:

Use get_subaccount_perpetual_positions instead

pub async fn get_subaccount_perpetual_positions( &self, subaccount: &Subaccount, opts: Option<ListPositionsOpts>, ) -> Result<Vec<PerpetualPositionResponseObject>, Error>

pub async fn list_parent_positions( &self, subaccount: &ParentSubaccount, opts: Option<ListPositionsOpts>, ) -> Result<Vec<PerpetualPositionResponseObject>, Error>

👎Deprecated since 0.3.0:

Use get_parent_subaccount_perpetual_positions instead

List all positions of a parent subaccount.

Reference.

pub async fn get_parent_subaccount_perpetual_positions( &self, subaccount: &ParentSubaccount, opts: Option<ListPositionsOpts>, ) -> Result<Vec<PerpetualPositionResponseObject>, Error>

List all positions of a parent subaccount.

Reference.

pub async fn get_asset_positions( &self, subaccount: &Subaccount, ) -> Result<Vec<AssetPositionResponseObject>, Error>

👎Deprecated since 0.3.0:

Use get_subaccount_asset_positions instead

Query for asset positions (size, buy/sell etc).

Reference.

pub async fn get_subaccount_asset_positions( &self, subaccount: &Subaccount, ) -> Result<Vec<AssetPositionResponseObject>, Error>

Query for asset positions (size, buy/sell etc).

Reference.

pub async fn get_parent_asset_positions( &self, subaccount: &ParentSubaccount, ) -> Result<Vec<AssetPositionResponseObject>, Error>

Query for asset positions (size, buy/sell etc) for a parent subaccount.

Reference.

pub async fn get_transfers( &self, subaccount: &Subaccount, opts: Option<GetTransfersOpts>, ) -> Result<Vec<TransferResponseObject>, Error>

👎Deprecated since 0.3.0:

Use get_subaccount_transfers instead

Query for transfers between subaccounts.

See also crate::node::NodeClient::transfer.

Reference.

pub async fn get_subaccount_transfers( &self, subaccount: &Subaccount, opts: Option<GetTransfersOpts>, ) -> Result<Vec<TransferResponseObject>, Error>

Query for transfers between subaccounts.

See also crate::node::NodeClient::transfer.

Reference.

pub async fn get_parent_transfers( &self, subaccount: &ParentSubaccount, opts: Option<GetTransfersOpts>, ) -> Result<Vec<ParentSubaccountTransferResponseObject>, Error>

👎Deprecated since 0.3.0:

Use get_parent_subaccount_number_transfers instead

Query for transfers between subaccounts associated with a parent subaccount.

See also crate::node::NodeClient::transfer.

Reference.

pub async fn get_parent_subaccount_number_transfers( &self, subaccount: &ParentSubaccount, opts: Option<GetTransfersOpts>, ) -> Result<Vec<ParentSubaccountTransferResponseObject>, Error>

Query for transfers between subaccounts associated with a parent subaccount.

See also crate::node::NodeClient::transfer.

Reference.

pub async fn list_orders( &self, subaccount: &Subaccount, opts: Option<ListOrdersOpts>, ) -> Result<ListOrdersResponse, Error>

👎Deprecated since 0.3.0:

Use get_subaccount_orders instead

Query for orders filtered by order params.

Reference.

pub async fn get_subaccount_orders( &self, subaccount: &Subaccount, opts: Option<ListOrdersOpts>, ) -> Result<ListOrdersResponse, Error>

Query for orders filtered by order params.

Reference.

pub async fn list_parent_orders( &self, subaccount: &ParentSubaccount, opts: Option<ListOrdersOpts>, ) -> Result<ListOrdersResponse, Error>

👎Deprecated since 0.3.0:

Use get_parent_subaccount_number_orders instead

Query for orders filtered by order params of a parent subaccount.

Reference.

pub async fn get_parent_subaccount_number_orders( &self, subaccount: &ParentSubaccount, opts: Option<ListOrdersOpts>, ) -> Result<ListOrdersResponse, Error>

Query for orders filtered by order params of a parent subaccount.

Reference.

pub async fn get_order( &self, order_id: &OrderId, ) -> Result<OrderResponseObject, Error>

Query for the order.

Reference.

pub async fn get_fills( &self, subaccount: &Subaccount, opts: Option<GetFillsOpts>, ) -> Result<Vec<FillResponseObject>, Error>

👎Deprecated since 0.3.0:

Use get_subaccount_fills instead

Query for fills (i.e. filled orders data).

Reference.

pub async fn get_subaccount_fills( &self, subaccount: &Subaccount, opts: Option<GetFillsOpts>, ) -> Result<Vec<FillResponseObject>, Error>

Query for fills (i.e. filled orders data).

Reference.

pub async fn get_parent_fills( &self, subaccount: &ParentSubaccount, opts: Option<GetFillsOpts>, ) -> Result<Vec<FillResponseObject>, Error>

👎Deprecated since 0.3.0:

Use get_parent_subaccount_number_fills instead

Query for fills (i.e. filled orders data) for a parent subaccount.

Reference.

pub async fn get_parent_subaccount_number_fills( &self, subaccount: &ParentSubaccount, opts: Option<GetFillsOpts>, ) -> Result<Vec<FillResponseObject>, Error>

Query for fills (i.e. filled orders data) for a parent subaccount.

Reference.

pub async fn get_historical_pnl( &self, subaccount: &Subaccount, opts: Option<GetHistoricalPnlOpts>, ) -> Result<Vec<PnlTicksResponseObject>, Error>

👎Deprecated since 0.3.0:

Use get_subaccount_historical_pnls instead

Query for profit and loss report for the specified time/block range.

Reference.

pub async fn get_subaccount_historical_pnls( &self, subaccount: &Subaccount, opts: Option<GetHistoricalPnlOpts>, ) -> Result<Vec<PnlTicksResponseObject>, Error>

Query for profit and loss report for the specified time/block range.

Reference.

pub async fn get_parent_historical_pnl( &self, subaccount: &ParentSubaccount, opts: Option<GetHistoricalPnlOpts>, ) -> Result<Vec<PnlTicksResponseObject>, Error>

👎Deprecated since 0.3.0:

Use get_parent_subaccount_number_historical_pnls instead

Query for profit and loss report for the specified time/block range of a parent subaccount.

Reference.

pub async fn get_parent_subaccount_number_historical_pnls( &self, subaccount: &ParentSubaccount, opts: Option<GetHistoricalPnlOpts>, ) -> Result<Vec<PnlTicksResponseObject>, Error>

Query for profit and loss report for the specified time/block range of a parent subaccount.

Reference.

pub async fn get_rewards( &self, address: &Address, opts: Option<GetTradingRewardsOpts>, ) -> Result<Vec<HistoricalBlockTradingReward>, Error>

👎Deprecated since 0.3.0:

Use get_historical_block_trading_rewards instead

Get trader’s rewards.

See also Trading Rewards.

Reference.

pub async fn get_historical_block_trading_rewards( &self, address: &Address, opts: Option<GetTradingRewardsOpts>, ) -> Result<Vec<HistoricalBlockTradingReward>, Error>

Get trader’s rewards.

See also Trading Rewards.

Reference.

pub async fn get_rewards_aggregated( &self, address: &Address, period: TradingRewardAggregationPeriod, opts: Option<GetAggregationsOpts>, ) -> Result<Vec<HistoricalTradingRewardAggregation>, Error>

👎Deprecated since 0.3.0:

Use get_historical_trading_rewards_aggregations instead

Get trader’s rewards aggregation.

See also Self::get_historical_block_trading_rewards.

Reference.

pub async fn get_historical_trading_rewards_aggregations( &self, address: &Address, period: TradingRewardAggregationPeriod, opts: Option<GetAggregationsOpts>, ) -> Result<Vec<HistoricalTradingRewardAggregation>, Error>

Get trader’s rewards aggregation.

See also Self::get_historical_block_trading_rewards.

Reference.

pub async fn get_transfers_between( &self, source_subaccount: &Subaccount, recipient_subaccount: &Subaccount, opts: Option<GetTransfersBetweenOpts>, ) -> Result<TransferBetweenResponse, Error>

Query for transfers between subaccounts.

Reference

pub async fn search_trader( &self, search_param: &str, ) -> Result<TraderSearchResponse, Error>

Search trader by query string (address, subaccount id, username, etc).

Reference

pub async fn get_funding_payments( &self, subaccount: &Subaccount, opts: Option<GetFundingPaymentsOpts>, ) -> Result<FundingPaymentResponse, Error>

Query for funding payments.

Reference.

pub async fn get_funding_payments_for_parent_subaccount( &self, subaccount: &ParentSubaccount, opts: Option<GetFundingPaymentsOpts>, ) -> Result<FundingPaymentResponse, Error>

Query for funding payments for a parent subaccount.

Reference.