pub enum FillType {
Limit,
Liquidated,
Liquidation,
Deleveraged,
Offsetting,
}Expand description
Fill type.
Variants
Limit
LIMIT is the fill type for a fill with a limit taker order.
Liquidated
LIQUIDATED is for the taker side of the fill where the subaccount was liquidated.
The subaccountId associated with this fill is the liquidated subaccount.
Liquidation
LIQUIDATION is for the maker side of the fill, never used for orders.
Deleveraged
DELEVERAGED is for the subaccount that was deleveraged in a deleveraging event.
The fill type will be set to taker.
Offsetting
OFFSETTING is for the offsetting subaccount in a deleveraging event.
The fill type will be set to maker.