Module telemetry

Module telemetry 

Telemetry.

Note that telemetry is available under the compilation feature telemetry (turned on by default).

Constants

TELEMETRY_BATCH_CANCEL_ORDER_DURATION
Histogram for batch_cancel_orders duration in milliseconds.
TELEMETRY_CANCEL_ORDER_DURATION
Histogram for cancel_order duration in milliseconds.
TELEMETRY_DESC_BATCH_CANCEL_ORDER_DURATION
Description for TELEMETRY_BATCH_CANCEL_ORDER_DURATION.
TELEMETRY_DESC_CANCEL_ORDER_DURATION
Description for TELEMETRY_CANCEL_ORDER_DURATION.
TELEMETRY_DESC_ORDERS_CANCELLED
Description for TELEMETRY_ORDERS_CANCELLED.
TELEMETRY_DESC_ORDERS_PLACED
Description for TELEMETRY_ORDERS_PLACED.
TELEMETRY_DESC_PLACE_ORDER_DURATION
Description for TELEMETRY_PLACE_ORDER_DURATION.
TELEMETRY_DESC_QUERY_TX_DURATION
Description for TELEMETRY_QUERY_TX_DURATION.
TELEMETRY_DESC_WS_RECEIVED
Description for TELEMETRY_WS_RECEIVED.
TELEMETRY_DESC_WS_RECONNECTS
Description for TELEMETRY_WS_RECONNECTS.
TELEMETRY_DESC_WS_SENT
Description for TELEMETRY_WS_SENT.
TELEMETRY_DESC_WS_SENT_DURATION
Description for TELEMETRY_WS_SENT_DURATION.
TELEMETRY_LABEL_ADDRESS
Label for address.
TELEMETRY_ORDERS_CANCELLED
Counter for orders cancelled with cancel_order.
TELEMETRY_ORDERS_PLACED
Counter for orders opened with place_order.
TELEMETRY_PLACE_ORDER_DURATION
Histogram for place_order duration in milliseconds.
TELEMETRY_QUERY_TX_DURATION
Histogram for query_transaction duration in milliseconds
TELEMETRY_WS_RECEIVED
Counter for messages received by Indexer Websocket feed.
TELEMETRY_WS_RECONNECTS
Counter for reconnection attempts for Indexer Websocket feed
TELEMETRY_WS_SENT
Counter for messages sent by Indexer Websocket feed.
TELEMETRY_WS_SENT_DURATION
Histogram for sending duration in milliseconds, Indexer Websocket feed messages.